Exceptions
==========

Here is a list of all exceptions defined by Bowtie.
Generally there shouldn't be a need to catch these but they are provided here for completeness.

.. automodule:: bowtie.exceptions
    :members:
